# Filters added to this controller apply to all controllers in the application.
# Likewise, all the methods added will be available for all controllers.

class ApplicationController < ActionController::Base
  filter_parameter_logging :password
  before_filter :initialize_user

  helper_method :logged_in?
  helper_method :admin?
  helper_method :time_left
  
  # See ActionController::RequestForgeryProtection for details
  # Uncomment the :secret if you're not using the cookie session store
  protect_from_forgery # :secret => '8374e6b474740f8ce7d9880797b996dc'
  
  protected
  def logged_in?
    @current_user.is_a?(User)
  end

  def initialize_user
    @current_user = User.find_by_id(session[:user]) if session[:user]
  end

  def admin?
    logged_in? && @current_user.admin?
  end

  def admin_required
    redirect_to_login unless admin?
  end

  def login_required
    redirect_to_login unless logged_in?
  end

  def redirect_to_login
    redirect_to(:controller => "sessions", :action => "new")
  end
  
  def time_left(initial_time)
    return 0 unless initial_time
    seconds_in_a_day = 60*60*24
    seconds_in_a_hour = 60*60
    seconds_in_a_min = 60
    timer = initial_time-Time.now.to_i
    timer.to_i
    
    # Let's extract the amount of days, hours, min, secs
    days = timer/seconds_in_a_day
    timer -= days*seconds_in_a_day
    hours = timer/seconds_in_a_hour
    timer -= hours*seconds_in_a_hour
    mins = timer/seconds_in_a_min
    timer -= mins*seconds_in_a_min
    
    text = ''
    if days > 0
      text += days.to_s + ' day'
      if days != 1
        text += 's, '
      else
        text += ', '
      end
    end
    if hours > 0
      text += hours.to_s + ' hour'
      if hours != 1
        text += 's, '
      else
        text += ', '
      end
    end
    if mins > 0
      text += mins.to_s + ' min'
      if mins != 1
        text += 's, '
      else
        text += ', '
      end
    end
    
    text += timer.to_s + ' sec'
    if timer != 1
      text += 's'
    end

    return text
  end
end
